@@ -179,7 +179,6 @@ class TestMetadata:
 
 
 class TestTags:
-
     tag = {
         "name": "MyTag",
         "description": "This tag gathers all API endpoints which are mine.",
@@ -196,7 +195,6 @@ class TestTags:
 
 
 class TestComponents(RefsSchemaTestMixin):
-
     properties = {
         "id": {"type": "integer", "format": "int64"},
         "name": {"type": "string", "example": "doggie"},
@@ -526,8 +524,8 @@ class TestComponents(RefsSchemaTestMixin):
         assert schemas["Pet_2"]["properties"] == self.properties
 
     def test_response_lazy(self, spec):
-        response_1 = {"description": "Reponse 1"}
-        response_2 = {"description": "Reponse 2"}
+        response_1 = {"description": "Response 1"}
+        response_2 = {"description": "Response 2"}
         spec.components.response("Response_1", response_1, lazy=False)
         spec.components.response("Response_2", response_2, lazy=True)
         responses = get_responses(spec)
@@ -1185,7 +1183,7 @@ class TestPlugins:
 class TestPluginsOrder:
     class OrderedPlugin(BasePlugin):
         def __init__(self, index, output):
-            super(TestPluginsOrder.OrderedPlugin, self).__init__()
+            super().__init__()
             self.index = index
             self.output = output
 
